@@ -14,23 +14,25 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.webrisk_v1.types import webrisk
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -218,6 +220,73 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -268,50 +337,22 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, WebRiskServiceTransport):
             # transport is a WebRiskServiceTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -323,6 +364,15 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -355,6 +405,27 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         ThreatList databases, this method needs to be called
         once for each list.
 
+
+
+        .. code-block::
+
+            from google.cloud import webrisk_v1
+
+            def sample_compute_threat_list_diff():
+                # Create a client
+                client = webrisk_v1.WebRiskServiceClient()
+
+                # Initialize request argument(s)
+                request = webrisk_v1.ComputeThreatListDiffRequest(
+                    threat_type="UNWANTED_SOFTWARE",
+                )
+
+                # Make the request
+                response = client.compute_threat_list_diff(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.webrisk_v1.types.ComputeThreatListDiffRequest, dict]):
                 The request object. Describes an API diff request.
@@ -398,7 +469,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([threat_type, version_token, constraints])
         if request is not None and has_flattened_params:
@@ -449,6 +520,28 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         not found on any of the requested ThreatList an empty
         response will be returned.
 
+
+
+        .. code-block::
+
+            from google.cloud import webrisk_v1
+
+            def sample_search_uris():
+                # Create a client
+                client = webrisk_v1.WebRiskServiceClient()
+
+                # Initialize request argument(s)
+                request = webrisk_v1.SearchUrisRequest(
+                    uri="uri_value",
+                    threat_types="UNWANTED_SOFTWARE",
+                )
+
+                # Make the request
+                response = client.search_uris(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.webrisk_v1.types.SearchUrisRequest, dict]):
                 The request object. Request to check URI entries against
@@ -479,7 +572,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([uri, threat_types])
         if request is not None and has_flattened_params:
@@ -528,6 +621,27 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         query this method to determine if there is a full hash
         match of a threat.
 
+
+
+        .. code-block::
+
+            from google.cloud import webrisk_v1
+
+            def sample_search_hashes():
+                # Create a client
+                client = webrisk_v1.WebRiskServiceClient()
+
+                # Initialize request argument(s)
+                request = webrisk_v1.SearchHashesRequest(
+                    threat_types="UNWANTED_SOFTWARE",
+                )
+
+                # Make the request
+                response = client.search_hashes(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.webrisk_v1.types.SearchHashesRequest, dict]):
                 The request object. Request to return full hashes
@@ -560,7 +674,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([hash_prefix, threat_types])
         if request is not None and has_flattened_params:
@@ -611,6 +725,31 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
         in the future. Only projects with CREATE_SUBMISSION_USERS
         visibility can use this method.
 
+
+
+        .. code-block::
+
+            from google.cloud import webrisk_v1
+
+            def sample_create_submission():
+                # Create a client
+                client = webrisk_v1.WebRiskServiceClient()
+
+                # Initialize request argument(s)
+                submission = webrisk_v1.Submission()
+                submission.uri = "uri_value"
+
+                request = webrisk_v1.CreateSubmissionRequest(
+                    parent="parent_value",
+                    submission=submission,
+                )
+
+                # Make the request
+                response = client.create_submission(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.webrisk_v1.types.CreateSubmissionRequest, dict]):
                 The request object. Request to send a potentially phishy
@@ -644,7 +783,7 @@ class WebRiskServiceClient(metaclass=WebRiskServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, submission])
         if request is not None and has_flattened_params:
