@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.webrisk_v1beta1.types import webrisk
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -105,6 +108,42 @@ class WebRiskServiceV1Beta1AsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return WebRiskServiceV1Beta1Client.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> WebRiskServiceV1Beta1Transport:
         """Returns the transport used by the client instance.
@@ -179,6 +218,25 @@ class WebRiskServiceV1Beta1AsyncClient:
     ) -> webrisk.ComputeThreatListDiffResponse:
         r"""Gets the most recent threat list diffs.
 
+        .. code-block::
+
+            from google.cloud import webrisk_v1beta1
+
+            def sample_compute_threat_list_diff():
+                # Create a client
+                client = webrisk_v1beta1.WebRiskServiceV1Beta1Client()
+
+                # Initialize request argument(s)
+                request = webrisk_v1beta1.ComputeThreatListDiffRequest(
+                    threat_type="UNWANTED_SOFTWARE",
+                )
+
+                # Make the request
+                response = client.compute_threat_list_diff(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.webrisk_v1beta1.types.ComputeThreatListDiffRequest, dict]):
                 The request object. Describes an API diff request.
@@ -214,7 +272,7 @@ class WebRiskServiceV1Beta1AsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([threat_type, version_token, constraints])
         if request is not None and has_flattened_params:
@@ -271,6 +329,27 @@ class WebRiskServiceV1Beta1AsyncClient:
         r"""This method is used to check whether a URI is on a
         given threatList.
 
+
+        .. code-block::
+
+            from google.cloud import webrisk_v1beta1
+
+            def sample_search_uris():
+                # Create a client
+                client = webrisk_v1beta1.WebRiskServiceV1Beta1Client()
+
+                # Initialize request argument(s)
+                request = webrisk_v1beta1.SearchUrisRequest(
+                    uri="uri_value",
+                    threat_types="UNWANTED_SOFTWARE",
+                )
+
+                # Make the request
+                response = client.search_uris(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.webrisk_v1beta1.types.SearchUrisRequest, dict]):
                 The request object. Request to check URI entries against
@@ -300,7 +379,7 @@ class WebRiskServiceV1Beta1AsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([uri, threat_types])
         if request is not None and has_flattened_params:
@@ -359,6 +438,26 @@ class WebRiskServiceV1Beta1AsyncClient:
         query this method to determine if there is a full hash
         match of a threat.
 
+
+        .. code-block::
+
+            from google.cloud import webrisk_v1beta1
+
+            def sample_search_hashes():
+                # Create a client
+                client = webrisk_v1beta1.WebRiskServiceV1Beta1Client()
+
+                # Initialize request argument(s)
+                request = webrisk_v1beta1.SearchHashesRequest(
+                    threat_types="UNWANTED_SOFTWARE",
+                )
+
+                # Make the request
+                response = client.search_hashes(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.webrisk_v1beta1.types.SearchHashesRequest, dict]):
                 The request object. Request to return full hashes
@@ -390,7 +489,7 @@ class WebRiskServiceV1Beta1AsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([hash_prefix, threat_types])
         if request is not None and has_flattened_params:
