@@ -246,20 +246,20 @@ def test_web_risk_service_client_client_options(
     # unsupported value.
     with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "Unsupported"}):
         with pytest.raises(MutualTLSChannelError):
-            client = client_class()
+            client = client_class(transport=transport_name)
 
     # Check the case GOOGLE_API_USE_CLIENT_CERTIFICATE has unsupported value.
     with mock.patch.dict(
         os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "Unsupported"}
     ):
         with pytest.raises(ValueError):
-            client = client_class()
+            client = client_class(transport=transport_name)
 
     # Check the case quota_project_id is provided
     options = client_options.ClientOptions(quota_project_id="octopus")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(transport=transport_name, client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -318,7 +318,7 @@ def test_web_risk_service_client_mtls_env_auto(
         )
         with mock.patch.object(transport_class, "__init__") as patched:
             patched.return_value = None
-            client = client_class(transport=transport_name, client_options=options)
+            client = client_class(client_options=options, transport=transport_name)
 
             if use_client_cert_env == "false":
                 expected_client_cert_source = None
@@ -395,6 +395,87 @@ def test_web_risk_service_client_mtls_env_auto(
                 )
 
 
+@pytest.mark.parametrize(
+    "client_class", [WebRiskServiceClient, WebRiskServiceAsyncClient]
+)
+@mock.patch.object(
+    WebRiskServiceClient,
+    "DEFAULT_ENDPOINT",
+    modify_default_endpoint(WebRiskServiceClient),
+)
+@mock.patch.object(
+    WebRiskServiceAsyncClient,
+    "DEFAULT_ENDPOINT",
+    modify_default_endpoint(WebRiskServiceAsyncClient),
+)
+def test_web_risk_service_client_get_mtls_endpoint_and_cert_source(client_class):
+    mock_client_cert_source = mock.Mock()
+
+    # Test the case GOOGLE_API_USE_CLIENT_CERTIFICATE is "true".
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "true"}):
+        mock_api_endpoint = "foo"
+        options = client_options.ClientOptions(
+            client_cert_source=mock_client_cert_source, api_endpoint=mock_api_endpoint
+        )
+        api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source(
+            options
+        )
+        assert api_endpoint == mock_api_endpoint
+        assert cert_source == mock_client_cert_source
+
+    # Test the case GOOGLE_API_USE_CLIENT_CERTIFICATE is "false".
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "false"}):
+        mock_client_cert_source = mock.Mock()
+        mock_api_endpoint = "foo"
+        options = client_options.ClientOptions(
+            client_cert_source=mock_client_cert_source, api_endpoint=mock_api_endpoint
+        )
+        api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source(
+            options
+        )
+        assert api_endpoint == mock_api_endpoint
+        assert cert_source is None
+
+    # Test the case GOOGLE_API_USE_MTLS_ENDPOINT is "never".
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "never"}):
+        api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source()
+        assert api_endpoint == client_class.DEFAULT_ENDPOINT
+        assert cert_source is None
+
+    # Test the case GOOGLE_API_USE_MTLS_ENDPOINT is "always".
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS_ENDPOINT": "always"}):
+        api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source()
+        assert api_endpoint == client_class.DEFAULT_MTLS_ENDPOINT
+        assert cert_source is None
+
+    # Test the case GOOGLE_API_USE_MTLS_ENDPOINT is "auto" and default cert doesn't exist.
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "true"}):
+        with mock.patch(
+            "google.auth.transport.mtls.has_default_client_cert_source",
+            return_value=False,
+        ):
+            api_endpoint, cert_source = client_class.get_mtls_endpoint_and_cert_source()
+            assert api_endpoint == client_class.DEFAULT_ENDPOINT
+            assert cert_source is None
+
+    # Test the case GOOGLE_API_USE_MTLS_ENDPOINT is "auto" and default cert exists.
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_CLIENT_CERTIFICATE": "true"}):
+        with mock.patch(
+            "google.auth.transport.mtls.has_default_client_cert_source",
+            return_value=True,
+        ):
+            with mock.patch(
+                "google.auth.transport.mtls.default_client_cert_source",
+                return_value=mock_client_cert_source,
+            ):
+                (
+                    api_endpoint,
+                    cert_source,
+                ) = client_class.get_mtls_endpoint_and_cert_source()
+                assert api_endpoint == client_class.DEFAULT_MTLS_ENDPOINT
+                assert cert_source == mock_client_cert_source
+
+
 @pytest.mark.parametrize(
     "client_class,transport_class,transport_name",
     [
@@ -413,7 +494,7 @@ def test_web_risk_service_client_client_options_scopes(
     options = client_options.ClientOptions(scopes=["1", "2"],)
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(transport=transport_name, client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file=None,
@@ -427,24 +508,31 @@ def test_web_risk_service_client_client_options_scopes(
 
 
 @pytest.mark.parametrize(
-    "client_class,transport_class,transport_name",
+    "client_class,transport_class,transport_name,grpc_helpers",
     [
-        (WebRiskServiceClient, transports.WebRiskServiceGrpcTransport, "grpc"),
+        (
+            WebRiskServiceClient,
+            transports.WebRiskServiceGrpcTransport,
+            "grpc",
+            grpc_helpers,
+        ),
         (
             WebRiskServiceAsyncClient,
             transports.WebRiskServiceGrpcAsyncIOTransport,
             "grpc_asyncio",
+            grpc_helpers_async,
         ),
     ],
 )
 def test_web_risk_service_client_client_options_credentials_file(
-    client_class, transport_class, transport_name
+    client_class, transport_class, transport_name, grpc_helpers
 ):
     # Check the case credentials file is provided.
     options = client_options.ClientOptions(credentials_file="credentials.json")
+
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
-        client = client_class(transport=transport_name, client_options=options)
+        client = client_class(client_options=options, transport=transport_name)
         patched.assert_called_once_with(
             credentials=None,
             credentials_file="credentials.json",
@@ -477,9 +565,74 @@ def test_web_risk_service_client_client_options_from_dict():
         )
 
 
-def test_compute_threat_list_diff(
-    transport: str = "grpc", request_type=webrisk.ComputeThreatListDiffRequest
+@pytest.mark.parametrize(
+    "client_class,transport_class,transport_name,grpc_helpers",
+    [
+        (
+            WebRiskServiceClient,
+            transports.WebRiskServiceGrpcTransport,
+            "grpc",
+            grpc_helpers,
+        ),
+        (
+            WebRiskServiceAsyncClient,
+            transports.WebRiskServiceGrpcAsyncIOTransport,
+            "grpc_asyncio",
+            grpc_helpers_async,
+        ),
+    ],
+)
+def test_web_risk_service_client_create_channel_credentials_file(
+    client_class, transport_class, transport_name, grpc_helpers
 ):
+    # Check the case credentials file is provided.
+    options = client_options.ClientOptions(credentials_file="credentials.json")
+
+    with mock.patch.object(transport_class, "__init__") as patched:
+        patched.return_value = None
+        client = client_class(client_options=options, transport=transport_name)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file="credentials.json",
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            client_cert_source_for_mtls=None,
+            quota_project_id=None,
+            client_info=transports.base.DEFAULT_CLIENT_INFO,
+            always_use_jwt_access=True,
+        )
+
+    # test that the credentials from file are saved and used as the credentials.
+    with mock.patch.object(
+        google.auth, "load_credentials_from_file", autospec=True
+    ) as load_creds, mock.patch.object(
+        google.auth, "default", autospec=True
+    ) as adc, mock.patch.object(
+        grpc_helpers, "create_channel"
+    ) as create_channel:
+        creds = ga_credentials.AnonymousCredentials()
+        file_creds = ga_credentials.AnonymousCredentials()
+        load_creds.return_value = (file_creds, None)
+        adc.return_value = (creds, None)
+        client = client_class(client_options=options, transport=transport_name)
+        create_channel.assert_called_with(
+            "webrisk.googleapis.com:443",
+            credentials=file_creds,
+            credentials_file=None,
+            quota_project_id=None,
+            default_scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            scopes=None,
+            default_host="webrisk.googleapis.com",
+            ssl_credentials=None,
+            options=[
+                ("grpc.max_send_message_length", -1),
+                ("grpc.max_receive_message_length", -1),
+            ],
+        )
+
+
+@pytest.mark.parametrize("request_type", [webrisk.ComputeThreatListDiffRequest, dict,])
+def test_compute_threat_list_diff(request_type, transport: str = "grpc"):
     client = WebRiskServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -513,10 +666,6 @@ def test_compute_threat_list_diff(
     assert response.new_version_token == b"new_version_token_blob"
 
 
-def test_compute_threat_list_diff_from_dict():
-    test_compute_threat_list_diff(request_type=dict)
-
-
 def test_compute_threat_list_diff_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -601,11 +750,17 @@ def test_compute_threat_list_diff_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].threat_type == webrisk.ThreatType.MALWARE
-        assert args[0].version_token == b"version_token_blob"
-        assert args[0].constraints == webrisk.ComputeThreatListDiffRequest.Constraints(
+        arg = args[0].threat_type
+        mock_val = webrisk.ThreatType.MALWARE
+        assert arg == mock_val
+        arg = args[0].version_token
+        mock_val = b"version_token_blob"
+        assert arg == mock_val
+        arg = args[0].constraints
+        mock_val = webrisk.ComputeThreatListDiffRequest.Constraints(
             max_diff_entries=1687
         )
+        assert arg == mock_val
 
 
 def test_compute_threat_list_diff_flattened_error():
@@ -654,11 +809,17 @@ async def test_compute_threat_list_diff_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].threat_type == webrisk.ThreatType.MALWARE
-        assert args[0].version_token == b"version_token_blob"
-        assert args[0].constraints == webrisk.ComputeThreatListDiffRequest.Constraints(
+        arg = args[0].threat_type
+        mock_val = webrisk.ThreatType.MALWARE
+        assert arg == mock_val
+        arg = args[0].version_token
+        mock_val = b"version_token_blob"
+        assert arg == mock_val
+        arg = args[0].constraints
+        mock_val = webrisk.ComputeThreatListDiffRequest.Constraints(
             max_diff_entries=1687
         )
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -680,7 +841,8 @@ async def test_compute_threat_list_diff_flattened_error_async():
         )
 
 
-def test_search_uris(transport: str = "grpc", request_type=webrisk.SearchUrisRequest):
+@pytest.mark.parametrize("request_type", [webrisk.SearchUrisRequest, dict,])
+def test_search_uris(request_type, transport: str = "grpc"):
     client = WebRiskServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -704,10 +866,6 @@ def test_search_uris(transport: str = "grpc", request_type=webrisk.SearchUrisReq
     assert isinstance(response, webrisk.SearchUrisResponse)
 
 
-def test_search_uris_from_dict():
-    test_search_uris(request_type=dict)
-
-
 def test_search_uris_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -774,8 +932,12 @@ def test_search_uris_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].uri == "uri_value"
-        assert args[0].threat_types == [webrisk.ThreatType.MALWARE]
+        arg = args[0].uri
+        mock_val = "uri_value"
+        assert arg == mock_val
+        arg = args[0].threat_types
+        mock_val = [webrisk.ThreatType.MALWARE]
+        assert arg == mock_val
 
 
 def test_search_uris_flattened_error():
@@ -815,8 +977,12 @@ async def test_search_uris_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].uri == "uri_value"
-        assert args[0].threat_types == [webrisk.ThreatType.MALWARE]
+        arg = args[0].uri
+        mock_val = "uri_value"
+        assert arg == mock_val
+        arg = args[0].threat_types
+        mock_val = [webrisk.ThreatType.MALWARE]
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -835,9 +1001,8 @@ async def test_search_uris_flattened_error_async():
         )
 
 
-def test_search_hashes(
-    transport: str = "grpc", request_type=webrisk.SearchHashesRequest
-):
+@pytest.mark.parametrize("request_type", [webrisk.SearchHashesRequest, dict,])
+def test_search_hashes(request_type, transport: str = "grpc"):
     client = WebRiskServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -861,10 +1026,6 @@ def test_search_hashes(
     assert isinstance(response, webrisk.SearchHashesResponse)
 
 
-def test_search_hashes_from_dict():
-    test_search_hashes(request_type=dict)
-
-
 def test_search_hashes_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -931,8 +1092,12 @@ def test_search_hashes_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].hash_prefix == b"hash_prefix_blob"
-        assert args[0].threat_types == [webrisk.ThreatType.MALWARE]
+        arg = args[0].hash_prefix
+        mock_val = b"hash_prefix_blob"
+        assert arg == mock_val
+        arg = args[0].threat_types
+        mock_val = [webrisk.ThreatType.MALWARE]
+        assert arg == mock_val
 
 
 def test_search_hashes_flattened_error():
@@ -972,8 +1137,12 @@ async def test_search_hashes_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].hash_prefix == b"hash_prefix_blob"
-        assert args[0].threat_types == [webrisk.ThreatType.MALWARE]
+        arg = args[0].hash_prefix
+        mock_val = b"hash_prefix_blob"
+        assert arg == mock_val
+        arg = args[0].threat_types
+        mock_val = [webrisk.ThreatType.MALWARE]
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -992,9 +1161,8 @@ async def test_search_hashes_flattened_error_async():
         )
 
 
-def test_create_submission(
-    transport: str = "grpc", request_type=webrisk.CreateSubmissionRequest
-):
+@pytest.mark.parametrize("request_type", [webrisk.CreateSubmissionRequest, dict,])
+def test_create_submission(request_type, transport: str = "grpc"):
     client = WebRiskServiceClient(
         credentials=ga_credentials.AnonymousCredentials(), transport=transport,
     )
@@ -1021,10 +1189,6 @@ def test_create_submission(
     assert response.uri == "uri_value"
 
 
-def test_create_submission_from_dict():
-    test_create_submission(request_type=dict)
-
-
 def test_create_submission_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
@@ -1153,8 +1317,12 @@ def test_create_submission_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
-        assert args[0].parent == "parent_value"
-        assert args[0].submission == webrisk.Submission(uri="uri_value")
+        arg = args[0].parent
+        mock_val = "parent_value"
+        assert arg == mock_val
+        arg = args[0].submission
+        mock_val = webrisk.Submission(uri="uri_value")
+        assert arg == mock_val
 
 
 def test_create_submission_flattened_error():
@@ -1194,8 +1362,12 @@ async def test_create_submission_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
-        assert args[0].parent == "parent_value"
-        assert args[0].submission == webrisk.Submission(uri="uri_value")
+        arg = args[0].parent
+        mock_val = "parent_value"
+        assert arg == mock_val
+        arg = args[0].submission
+        mock_val = webrisk.Submission(uri="uri_value")
+        assert arg == mock_val
 
 
 @pytest.mark.asyncio
@@ -1234,6 +1406,23 @@ def test_credentials_transport_error():
             transport=transport,
         )
 
+    # It is an error to provide an api_key and a transport instance.
+    transport = transports.WebRiskServiceGrpcTransport(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    options = client_options.ClientOptions()
+    options.api_key = "api_key"
+    with pytest.raises(ValueError):
+        client = WebRiskServiceClient(client_options=options, transport=transport,)
+
+    # It is an error to provide an api_key and a credential.
+    options = mock.Mock()
+    options.api_key = "api_key"
+    with pytest.raises(ValueError):
+        client = WebRiskServiceClient(
+            client_options=options, credentials=ga_credentials.AnonymousCredentials()
+        )
+
     # It is an error to provide scopes and a transport instance.
     transport = transports.WebRiskServiceGrpcTransport(
         credentials=ga_credentials.AnonymousCredentials(),
@@ -1707,7 +1896,7 @@ def test_parse_common_location_path():
     assert expected == actual
 
 
-def test_client_withDEFAULT_CLIENT_INFO():
+def test_client_with_default_client_info():
     client_info = gapic_v1.client_info.ClientInfo()
 
     with mock.patch.object(
@@ -1772,3 +1961,33 @@ def test_client_ctx():
             with client:
                 pass
             close.assert_called()
+
+
+@pytest.mark.parametrize(
+    "client_class,transport_class",
+    [
+        (WebRiskServiceClient, transports.WebRiskServiceGrpcTransport),
+        (WebRiskServiceAsyncClient, transports.WebRiskServiceGrpcAsyncIOTransport),
+    ],
+)
+def test_api_key_credentials(client_class, transport_class):
+    with mock.patch.object(
+        google.auth._default, "get_api_key_credentials", create=True
+    ) as get_api_key_credentials:
+        mock_cred = mock.Mock()
+        get_api_key_credentials.return_value = mock_cred
+        options = client_options.ClientOptions()
+        options.api_key = "api_key"
+        with mock.patch.object(transport_class, "__init__") as patched:
+            patched.return_value = None
+            client = client_class(client_options=options)
+            patched.assert_called_once_with(
+                credentials=mock_cred,
+                credentials_file=None,
+                host=client.DEFAULT_ENDPOINT,
+                scopes=None,
+                client_cert_source_for_mtls=None,
+                quota_project_id=None,
+                client_info=transports.base.DEFAULT_CLIENT_INFO,
+                always_use_jwt_access=True,
+            )
